# X AI API Key Setup

1. Create an X AI API key at: https://x.ai/api

2. Enter ".apikeys" in ToolMate AI prompt or select `change API keys` via action menu.

3. Follow the prompts and enter your X AI API key(s)

4. Enter `.model` in ToolMate AI prompt or select `change AI backends and models` via action menu.

5. Select `X AI API` as the AI platform.